interface BasePaymentHeader {
    applicationData?: string;
    publicKeyHash: string;
    transactionId: string;
}
interface ECPaymentHeader extends BasePaymentHeader {
    ephemeralPublicKey: string;
}
interface RSAPaymentHeader extends BasePaymentHeader {
    wrappedKey: string;
}
interface BasePaymentTokenPaymentData {
    /**
     * Encrypted payment data dictionary, Base64 encoded
     */
    data: string;
    /**
     * Signature of the payment and header data, Base64 encoded
     */
    signature: string;
}
export interface ECPaymentTokenPaymentData extends BasePaymentTokenPaymentData {
    version: 'EC_v1';
    header: ECPaymentHeader;
}
export interface RSAPaymentTokenPaymentData extends BasePaymentTokenPaymentData {
    version: 'RSA_v1';
    header: RSAPaymentHeader;
}
export type PaymentTokenPaymentData = ECPaymentTokenPaymentData | RSAPaymentTokenPaymentData;
interface ThreeDSDetailedPaymentData {
    /**
     * Online payment cryptogram, as defined by 3D Secure. Base64 encoded
     */
    onlinePaymentCryptogram: string;
    /**
     * ECI indicator, as defined by 3D Secure.
     *
     * The card network may add an ECI indicator to the payment data that the payment token includes.
     *
     * If you receive an ECI indicator, you must pass it on to your payment processor; otherwise, the transaction fails.
     */
    eciIndicator?: string;
}
interface EMVDetailedPaymentData {
    /**
     * The Europay, Mastercard, and Visa (EMV) payment structure, as a Base64-encoded string
     *
     * Output from the Secure Element
     */
    emvData: string;
    /**
     * The encrypted PIN, as a hex-encoded string.
     *
     * The PIN is encrypted using the bank’s key.
     *
     * RSA_v1 only.
     */
    encryptedPINData?: string;
}
interface AuthenticationResponse {
    /**
     * The submerchant identifier as provided by the coordinator merchant
     */
    merchantIdentifier: string;
    /**
     * Payment network-generated cryptogram for the submerchant
     */
    authenticationData: string;
    /**
     * The authorized amount for a given submerchant
     */
    transactionAmount: string;
}
interface MerchantTokenMetadata {
    /**
     * An array containing data you use to display art that represents the card related to the merchant token.
     */
    cardArt: {
        /**
         * A name representing the bank and the card used for the transaction.
         */
        name: string;
        /**
         * The card type.
         */
        type: string;
        /**
         * The URL for downloading the card art, as provided by the issuing bank.
         */
        url: string;
    }[];
    /**
     * Card data, including its expiration date and suffix, for the card related to the merchant token.
     */
    cardMetadata: {
        /**
         * The card’s expiration date.
         */
        expirationDate: string;
        /**
         * The last four digits of a card’s number.
         */
        fpanSuffix: string;
    };
}
interface BaseDecryptedPaymentData {
    /**
     * Device-specific account number of the card that funds this transaction.
     * A.K.A. "DPAN"
     */
    applicationPrimaryAccountNumber: string;
    /**
     * Card expiration date in the format YYMMDD
     */
    applicationExpirationDate: string;
    /**
     * ISO 4217 numeric currency code, as a string to preserve leading zeros
     */
    currencyCode: string;
    /**
     * Transaction amount
     */
    transactionAmount: number;
    /**
     * Optional. Cardholder name.
     */
    cardholderName?: string;
    /**
     * Hex-encoded device manufacturer identifier
     */
    deviceManufacturerIdentifier: string;
    /**
     * For a multitoken request, a list of submerchant responses that contain cryptograms.
     */
    authenticationResponses?: AuthenticationResponse[];
    /**
     * For a merchant token request, the provisioned merchant token identifier from the payment network
     */
    merchantTokenIdentifier?: string;
    /**
     * For a merchant token request, this data contains card art and the token's last four digits and expiration date
     */
    merchantTokenMetadata?: MerchantTokenMetadata;
}
interface ThreeDSDecryptedPaymentData extends BaseDecryptedPaymentData {
    paymentDataType: '3DSecure';
    /**
     * Detailed payment data
     */
    paymentData: ThreeDSDetailedPaymentData;
}
interface EMVDecryptedPaymentData extends BaseDecryptedPaymentData {
    paymentDataType: 'EMV';
    /**
     * Detailed payment data
     */
    paymentData: EMVDetailedPaymentData;
}
export type DecryptedPaymentData = ThreeDSDecryptedPaymentData | EMVDecryptedPaymentData;
export interface DecryptionStrategy<T extends PaymentTokenPaymentData> {
    decrypt(paymentData: T): DecryptedPaymentData;
}
type ApplePayPaymentMethodType = 'debit' | 'credit' | 'prepaid' | 'store';
type ApplePayPaymentPassActivationState = 'activated' | 'requiresActivation' | 'activating' | 'suspended' | 'deactivated';
interface ApplePayPaymentPass {
    primaryAccountIdentifier: string;
    primaryAccountNumberSuffix: string;
    deviceAccountIdentifier?: string;
    deviceAccountNumberSuffix?: string;
    activationState: ApplePayPaymentPassActivationState;
}
interface ApplePayPaymentContact {
    phoneNumber: string;
    emailAddress: string;
    givenName: string;
    familyName: string;
    phoneticGivenName: string;
    phoneticFamilyName: string;
    addressLines: string[];
    subLocality: string;
    locality: string;
    postalCode: string;
    subAdministrativeArea: string;
    administrativeArea: string;
    country: string;
    countryCode: string;
}
interface ApplePayPaymentMethod {
    displayName?: string;
    network?: string;
    type?: ApplePayPaymentMethodType;
    paymentPass?: ApplePayPaymentPass;
    billingContact?: ApplePayPaymentContact;
}
export interface ApplePayPaymentToken {
    paymentMethod: ApplePayPaymentMethod;
    transactionIdentifier?: string;
    paymentData?: PaymentTokenPaymentData;
}
export interface ApplePayPayment {
    token: ApplePayPaymentToken;
    billingContact?: ApplePayPaymentContact;
    shippingContact?: ApplePayPaymentContact;
}
export class RsaDecryptionStrategy implements DecryptionStrategy<RSAPaymentTokenPaymentData> {
    constructor({ privateKeyPem }: ApplePayMerchantConfiguration);
    /**
     * Decrypting the token using the PEM formatted merchant certificate and private key (the latter of which, at least, is managed by a third-party)
     */
    decrypt(paymentData: RSAPaymentTokenPaymentData): DecryptedPaymentData;
}
export interface ApplePayMerchantConfiguration {
    /**
     * (Optional) Merchant identifier, used for tracking errors.
     */
    identifier?: string;
    /**
     * Payment processing certificate issued by Apple for the merchant in PEM format.
     */
    certificatePem: Buffer;
    /**
     * Payment processing private key created by the Merchant in PEM format.
     */
    privateKeyPem: Buffer;
}
export interface ApplePaymentTokenContextOptions {
    merchants: ApplePayMerchantConfiguration[];
}
/**
 * Context used for decrypting Apple Payment Tokens.
 */
export class ApplePaymentTokenContext {
    constructor(options: ApplePaymentTokenContextOptions);
    decrypt(paymentData: PaymentTokenPaymentData): DecryptedPaymentData;
}
export class EcDecryptionStrategy implements DecryptionStrategy<ECPaymentTokenPaymentData> {
    constructor({ certificatePem, privateKeyPem, }: ApplePayMerchantConfiguration);
    /**
     * Decrypting the token using the PEM formatted merchant certificate and private key (the latter of which, at least, is managed by a third-party)
     */
    decrypt(paymentData: ECPaymentTokenPaymentData): DecryptedPaymentData;
}

//# sourceMappingURL=types.d.ts.map
